Changelog
=========

0.0.3 (2020-07-28)
------------------

- `poll.py`: added ability to split images into grid of equal sized images, obtaining
  a classification for each sub-image.
- fixed license: now uses Apache 2.0 instead of MIT


0.0.2 (2019-11-14)
------------------

- added missing `MANIFEST.in`


0.0.1 (2019-11-01)
------------------

- initial release
